==> x265_2.4.tar.gz: x265_2.4/source/dynamicHDR10/BasicStructures.h <==
/**
 * @file                       BasicStructures.h
 * @brief                      Defines the structure of metadata parameters
 * @author                     Daniel Maximiliano Valenzuela, Seongnam Oh.
 * @create date                03/01/2017
 * @version                    0.0.1
 *
 * Copyright @ 2017 Samsung Electronics, DMS Lab, Samsung Research America and Samsung Research Tijuana
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
**/

#ifndef BASICSTRUCTURES_H
#define BASICSTRUCTURES_H

#include <vector>


struct LuminanceParameters
{
    float averageLuminance = 0.0;
    float maxRLuminance = 0.0;
    float maxGLuminance = 0.0;
    float maxBLuminance = 0.0;
    int order;
    std::vector<unsigned int> percentiles;
};

struct BezierCurveData
{
    int order;
    int sPx;
    int sPy;
    std::vector<int> coeff;
};

#endif // BASICSTRUCTURES_H

==> x265_2.5.orig.tar.gz: x265_2.5/source/dynamicHDR10/BasicStructures.h <==
/**
 * @file                       BasicStructures.h
 * @brief                      Defines the structure of metadata parameters
 * @author                     Daniel Maximiliano Valenzuela, Seongnam Oh.
 * @create date                03/01/2017
 * @version                    0.0.1
 *
 * Copyright @ 2017 Samsung Electronics, DMS Lab, Samsung Research America and Samsung Research Tijuana
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
**/

#ifndef BASICSTRUCTURES_H
#define BASICSTRUCTURES_H

#include <vector>


struct LuminanceParameters
{
    float averageLuminance = 0.0;
    float maxRLuminance = 0.0;
    float maxGLuminance = 0.0;
    float maxBLuminance = 0.0;
    int order = 0;
    std::vector<unsigned int> percentiles;
};

struct BezierCurveData
{
    int order = 0;
    int sPx = 0;
    int sPy = 0;
    std::vector<int> coeff;
};

struct PercentileLuminance{

    float averageLuminance = 0.0;
    float maxRLuminance = 0.0;
    float maxGLuminance = 0.0;
    float maxBLuminance = 0.0;
    int order = 0;
    std::vector<unsigned int> percentiles;
};

#endif // BASICSTRUCTURES_H
